Relational Transformer Encoder/Decoder Layers
---------------------------------------------
This contains the relational encoder and decoder layers with sparse/dense relations among inputs.

.. autoclass:: mi_module_zoo.relationaltransformerlayers.RelationalTransformerEncoderLayer
   :members: forward
   :undoc-members:

.. autoclass:: mi_module_zoo.relationaltransformerlayers.RelationalTransformerDecoderLayer
   :members: forward
   :undoc-members:
